@@ -7,14 +7,11 @@ from .auth import Authentication
 
 
 class RESTClient:
-    def __init__(
-        self, url: str, *, authentication: Authentication = None, msgpack: bool = False,
-    ):
+    def __init__(self, url: str, *, authentication: Authentication = None):
         super().__init__()
         self._url = url.rstrip("/")
         self._auth = authentication
         self._session = requests.Session()
-        self._msgpack = msgpack
 
     @property
     def url(self):
@@ -24,7 +21,11 @@ class RESTClient:
     def session(self):
         return self._session
 
-    def _construct_url(self, resource: Union[str, Iterable[str]]) -> str:
+    def _construct_url(
+        self, resource: Optional[Union[str, Iterable[str]]] = None
+    ) -> str:
+        if resource is None:
+            return self.url
         if isinstance(resource, str):
             return "/".join((self.url, resource))
         return "/".join((self.url, *resource))
@@ -37,73 +38,98 @@ class RESTClient:
 
     def get(
         self,
-        resource: Union[str, Iterable[str]],
+        resource: Optional[Union[str, Iterable[str]]] = None,
         *,
         parameters: Optional[dict] = None,
         data: Optional[Union[dict, List[dict]]] = None,
         headers: Optional[dict] = None,
+        msgpack_data: Optional[bool] = None,
     ) -> Union[dict, List[dict]]:
         """Get data located at a resource"""
-        return self._request(
-            "get", resource, parameters=parameters, data=data, headers=headers
+        return self.request(
+            "get",
+            resource,
+            parameters=parameters,
+            data=data,
+            headers=headers,
+            msgpack_data=msgpack_data,
         )
 
     def put(
         self,
-        resource: Union[str, Iterable[str]],
+        resource: Optional[Union[str, Iterable[str]]] = None,
         *,
         parameters: Optional[dict] = None,
         data: Optional[Union[dict, List[dict]]] = None,
         headers: Optional[dict] = None,
+        msgpack_data: Optional[bool] = None,
     ):
         """Overwrite data located at a resource"""
-        return self._request(
-            "put", resource, parameters=parameters, data=data, headers=headers
+        return self.request(
+            "put",
+            resource,
+            parameters=parameters,
+            data=data,
+            headers=headers,
+            msgpack_data=msgpack_data,
         )
 
     def post(
         self,
-        resource: Union[str, Iterable[str]],
+        resource: Optional[Union[str, Iterable[str]]] = None,
         *,
         parameters: Optional[dict] = None,
         data: Optional[Union[dict, List[dict]]] = None,
         headers: Optional[dict] = None,
+        msgpack_data: Optional[bool] = None,
     ):
         """Send data to a resource"""
-        return self._request(
-            "post", resource, parameters=parameters, data=data, headers=headers
+        return self.request(
+            "post",
+            resource,
+            parameters=parameters,
+            data=data,
+            headers=headers,
+            msgpack_data=msgpack_data,
         )
 
     def delete(
         self,
-        resource: Union[str, Iterable[str]],
+        resource: Optional[Union[str, Iterable[str]]] = None,
         *,
         parameters: Optional[dict] = None,
         data: Optional[Union[dict, List[dict]]] = None,
         headers: Optional[dict] = None,
+        msgpack_data: Optional[bool] = None,
     ):
         """Delete data located at a resource"""
-        return self._request(
-            "delete", resource, parameters=parameters, data=data, headers=headers
+        return self.request(
+            "delete",
+            resource,
+            parameters=parameters,
+            data=data,
+            headers=headers,
+            msgpack_data=msgpack_data,
         )
 
-    def _request(
+    def request(
         self,
         method: str,
-        resource: Union[str, Iterable[str]],
+        resource: Optional[Union[str, Iterable[str]]] = None,
         *,
         parameters: Optional[dict] = None,
         data: Optional[Union[dict, List[dict]]] = None,
         headers: Optional[dict] = None,
+        msgpack_data: Optional[bool] = None,
     ):
         headers = headers or {}
         if self._auth:
             headers["Authorization"] = f"Bearer {self._auth.get_access_token()}"
-        if self._msgpack:
+        if msgpack_data:
             headers["accept"] = "application/x-msgpack"
         json = None
         if data is not None:
-            if self._msgpack:
+            if msgpack_data:
                 data = msgpack.packb(data)
                 headers["content-type"] = "application/x-msgpack"
             else:
